/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the Ext EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 * 
 * [1] http://treleis.org/licensing/specification-eoa-ext-license.html
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.binding.http.rt;

import java.util.Map;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.ext.connector.db.DataSourceConnector;

/**
 * Defines configuration used to configure a runtime <code>HTTPBinding</code> component
 * provider.
 */
public class HTTPBindingConfiguration {

    // initialize all instance vars with reasonable defaults

    private boolean embedStackTraceInFaults = true;
    private Map<QName, Integer> requestorTimeout;
    private int maxPayloadProcessors = 5;
    private String dataSourceConnectorName = DataSourceConnector.SYSTEM_DATA_SOURCE;

    /**
     * Gets amount of time before a blocking request times out, i.e the amount of time provider
     * will spend waiting on an anonymous response before throwing a fault.
     * 
     * @return value in milliseconds or -1 to indicate no timeout.
     */
    public int getRequestorTimeout(QName operationName) {
        int answer = 60000; // default to 1 minute
        if (requestorTimeout != null) {
            Integer integer = requestorTimeout.get(operationName);
            if (integer != null) {
                answer = integer.intValue();
            }
        }
        return answer;
    }

    public void setRequestorTimeout(Map<QName, Integer> requestorTimeout) {
        this.requestorTimeout = requestorTimeout;
    }

    /**
     * Defines DataSourceConnector name which MAY be required by binding provider to implement
     * message and/or header persistence. If element is undefined, the connector
     * 'SystemDataSource' is implied.
     * 
     * @return
     */
    public String getDataSourceConnectorName() {
        return dataSourceConnectorName;
    }
    
    public void setDataSourceConnectorName(String dataSourceConnectorName) {
        this.dataSourceConnectorName = dataSourceConnectorName;
    }

    /**
     * Defines maximum number of concurrent processors which process message payload, i.e.
     * which process action by binding it according to wsdl description and then passing to
     * engine.
     * 
     * @return
     */
    public int getMaxPayloadProcessors() {
        return maxPayloadProcessors;
    }

    public void setMaxPayloadProcessors(int maxPayloadProcessors) {
        this.maxPayloadProcessors = maxPayloadProcessors;
    }

    /**
     * Constrains fault handling.
     * 
     * @return true if stack trace embedded in detail. false if not.
     */
    public boolean isEmbeddStackTraceInFaults() {
        return embedStackTraceInFaults;
    }

    public void setEmbeddStackTraceInFaults(boolean embedStackTraceInFaults) {
        this.embedStackTraceInFaults = embedStackTraceInFaults;
    }

}
